# is_probably_hash

## Description

`is_probably_hash` is a lightweight Python library to check if particular string can be a hash. Just put particular string, and it will return boolean. Note that when it returns `true`, it means the string is possibly valid hash, but not necessarily must be hash.

Support popular hashes like MD5, SHA1, SHA256, and SHA512. Submit issue or PR for more support. 

## Installation
```bash
pip install is_probably_hash

```

Or install directly from source:

```bash
git clone https://github.com/yogski/is_probably_hash.git
cd is_probably_hash
pip install .
```

## License
This project is licensed under the MIT License.

## Contributing
Contributions are welcome! Please open an issue or submit a pull request.